==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/config/e2_option.h <==
/* $Id: e2_option.h 1019 2005-08-11 01:57:01Z tpgww $
 * 
 * Copyright (C) 2003-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_OPTION_H
#define E2_OPTION_H

#include "emelfm2.h"

typedef enum
{
	//simple types
	E2_OPTION_TYPE_BOOL = 1,
	E2_OPTION_TYPE_INT,
	E2_OPTION_TYPE_STR,
	E2_OPTION_TYPE_SEL,
	E2_OPTION_TYPE_FONT,
	E2_OPTION_TYPE_COLOR,
	E2_OPTION_TYPE_FILE,	//UNUSED
	E2_OPTION_TYPE_ICON,
	E2_OPTION_TYPE_TREE,
} E2_OptionType;

//these are flags that may be set when a tree option is registered
//stored at set->ex.tree.flags
typedef enum
{
	E2_OPTION_TREE_UP_DOWN = 1 << 0,
	E2_OPTION_TREE_ADD_DEL = 1 << 1,
	E2_OPTION_TREE_LAST_COL_EMPTY = 1 << 2,
	E2_OPTION_TREE_LIST = 1 << 3,
	
	//this is set/cleared in or around a config dialog, as a signal
	//that the set has been edited
	E2_OPTION_TREE_SET_EDITED = 1<< 8,

} E2_OptionTreeTypeFlags;

typedef struct _E2_OptionTypeExtraInt
{
	gint min;
	gint max;
} E2_OptionTypeExtraInt;

typedef struct _E2_OptionTypeExtraSel
{
	gchar **def;
	gint def_count;
} E2_OptionTypeExtraSel;

//stored as set->ex.tree
typedef struct _E2_OptionTypeExtraTree
{
	gpointer model;
	//array of strings with default values for the tree
	gchar **def;
	//holds tree values in case the config file
	//has been read before the tree option was registed
//	gchar **unknown;
//	gint def_num;
	gboolean found_in_config_file;
	gint columns_num;
	GList *columns;
	gpointer selection_check_func;
	gpointer draggable_check_func;
	E2_OptionTreeTypeFlags flags; //flags set when registering a tree option
} E2_OptionTypeExtraTree;

typedef struct _E2_OptionTypeExtraColor
{
	GdkColor value;
} E2_OptionTypeExtraColor;


typedef enum
{
	E2_OPTION_FLAG_BASIC = 1 << 0,
	E2_OPTION_FLAG_BASICONLY = 1 << 1,
	E2_OPTION_FLAG_ADVANCED = 1 << 2,
	E2_OPTION_FLAG_HIDDEN = 1 << 3,	//for items not shown in config dialog
	//signals for things to free when config data is dumped
	E2_OPTION_FLAG_BOOL = 1 << 4,
	E2_OPTION_FLAG_INT = 1 << 5,
	E2_OPTION_FLAG_STR = 1 << 6,
	E2_OPTION_FLAG_SEL = 1 << 7,
	E2_OPTION_FLAG_FONT = 1 << 8,
	E2_OPTION_FLAG_COLOR = 1 << 9,
	E2_OPTION_FLAG_FILE = 1 << 10,	//corresponds to an option-type not presently used
	E2_OPTION_FLAG_ICON = 1 << 11,
	E2_OPTION_FLAG_TREE = 1 << 12,
	//more flags for things to free when the config data is dumped
	E2_OPTION_FLAG_FREENAME = 1 << 14,
	E2_OPTION_FLAG_FREEGROUP = 1 << 15,
	E2_OPTION_FLAG_FREEDESC = 1 << 16,
	E2_OPTION_FLAG_FREETIP = 1 << 17,
	//flags for things to rebuild when config dialog is completed
	E2_OPTION_FLAG_BUILDALL = 1 << 20,
	E2_OPTION_FLAG_BUILDPANES = 1 << 21,
	E2_OPTION_FLAG_BUILDLISTS = 1 << 22,
	E2_OPTION_FLAG_BUILDBARS = 1 << 23,
	E2_OPTION_FLAG_BUILDSAMEBARS = 1 << 24,
	//flags for 'extra' data structures to possibly rebuild when config dialog is completed
	E2_OPTION_FLAG_BUILDFILES = 1 << 25,	//dirty filetypes tree option
	E2_OPTION_FLAG_BUILDPLUGS = 1 << 26, //dirty plugins tree option
	E2_OPTION_FLAG_BUILDKEYS = 1 << 27, //dirty keybindings tree option
	E2_OPTION_FLAG_BUILDALIAS = 1 << 28, //dirty aliases tree option
} E2_OptionFlags;

typedef struct _E2_OptionSet
{
	E2_OptionType type;
	gchar *name;	//constant string, 'internal' name of option, used for checking, finding
	gchar *group;	//probably always a newly-alllocated string
	gchar *desc;	//almost always a constant string
	gchar *tip;	//almost always a constant string
	gchar *depends;	//constant string, 'internal' name of option that must be true for this
							//one to be 'changeable', or can start with "!" for false precedent
	gint ival;
	gchar *sval;
//	gint idef;
//	gchar *sdef;
	
	//extra option data
	union _E2_OptionTypeExtra
	{
		E2_OptionTypeExtraInt num;
		E2_OptionTypeExtraSel sel;
		E2_OptionTypeExtraTree tree;
		E2_OptionTypeExtraColor color;
	} ex;
	GtkWidget *widget;	//config dialog widget with data for this option
	E2_OptionFlags flags;	//flags for destroying, rebuilding stuff related to the option
	gboolean hook_freezed;
	GHookList hook_value_changed;
} E2_OptionSet;

typedef gchar *_config_labels[50];
_config_labels config_labels;
#define _C(d) config_labels[d]

gchar *default_config_file;

//to save option references
GHashTable *options_hash;
//GHashTable *options_queue; was for unknown options
GPtrArray *options_array;

void e2_option_icons_init (void);
void e2_option_setup_labels (void);
gboolean e2_option_check_config_dir (void);
gboolean e2_option_check_config_files (void);
void e2_option_disable_config_checks (void);
void e2_option_enable_config_checks (void);
void e2_option_restore_defaults (void);
void e2_option_refresh (gboolean reload, gboolean recreate);
void e2_option_set_trash_dir (void);
void e2_option_init (void);
void e2_option_read_from_string (gchar *f[]);
void e2_option_register (E2_OptionSet *set);
E2_OptionSet *e2_option_get (gchar *option);
E2_OptionSet *e2_option_get_simple (gchar *option);
//void *e2_option_void_get (E2_OptionSet *set, gchar *option);
void e2_option_tree_stores_clear (void);
E2_OptionSet *e2_option_attach_value_changed (gchar *option, GtkWidget *widget,
	gpointer func, gpointer data);
void e2_option_attach_value_changed_simple (E2_OptionSet *set, GtkWidget *widget,
	gpointer func, gpointer data);
gboolean e2_option_file_read (void);
void e2_option_file_write (void);

//void destroy_config ();

#include "e2_option_bool.h"
#include "e2_option_int.h"
#include "e2_option_str.h"
#include "e2_option_sel.h"
#include "e2_option_color.h"
#include "e2_option_tree.h"
#include "e2_option_unknown.h"

  /***********************************************/
 /***** functions from e2_option__default.c *****/
/***********************************************/

void e2_option_default_register (void);

  /******************************************/
 /***** functions from e2_option__io.c *****/
/******************************************/

//gboolean e2_option_read_from_file (gchar *fn);
//void e2_option_write_to_file (void);

  /**********************************************/
 /***** functions from e2_option__widget.c *****/
/**********************************************/

GtkWidget *e2_option_create_menu (GtkWidget *controller, GtkWidget *menu,
	E2_OptionSet *set, ...);
void e2_option_connect (GtkWidget *controller, gboolean  active);

#endif //ndef E2_OPTION_H

==> emelfm2-0.1.4.tar.gz: emelfm2-0.1.4/src/config/e2_option.h <==
/* $Id: e2_option.h 1425 2005-12-03 02:22:50Z tpgww $
 * 
 * Copyright (C) 2003-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_OPTION_H
#define E2_OPTION_H

#include "emelfm2.h"

typedef enum
{
	//simple types
	E2_OPTION_TYPE_BOOL = 1,
	E2_OPTION_TYPE_INT,
	E2_OPTION_TYPE_STR,
	E2_OPTION_TYPE_SEL,
	E2_OPTION_TYPE_FONT,
	E2_OPTION_TYPE_COLOR,
	E2_OPTION_TYPE_FILE,	//UNUSED
	E2_OPTION_TYPE_ICON,
	E2_OPTION_TYPE_TREE,
} E2_OptionType;

//these are flags that may be set when a tree option is registered
//stored at set->ex.tree.flags
typedef enum
{
	E2_OPTION_TREE_UP_DOWN = 1 << 0,
	E2_OPTION_TREE_ADD_DEL = 1 << 1,
	E2_OPTION_TREE_LAST_COL_EMPTY = 1 << 2,
	E2_OPTION_TREE_LIST = 1 << 3,
	
	//this is set/cleared in or around a config dialog, as a signal
	//that the set has been edited
	E2_OPTION_TREE_SET_EDITED = 1<< 8,

} E2_OptionTreeTypeFlags;

typedef enum
{
	E2_OPTION_FLAG_BASIC = 1 << 0,
	E2_OPTION_FLAG_BASICONLY = 1 << 1,
	E2_OPTION_FLAG_ADVANCED = 1 << 2,
	E2_OPTION_FLAG_HIDDEN = 1 << 3,	//for items not shown in config dialog
	//signals for things to free when config data is dumped
	E2_OPTION_FLAG_BOOL = 1 << 4,
	E2_OPTION_FLAG_INT = 1 << 5,
	E2_OPTION_FLAG_STR = 1 << 6,
	E2_OPTION_FLAG_SEL = 1 << 7,
	E2_OPTION_FLAG_FONT = 1 << 8,
	E2_OPTION_FLAG_COLOR = 1 << 9,
	E2_OPTION_FLAG_FILE = 1 << 10,	//corresponds to an option-type not presently used
	E2_OPTION_FLAG_ICON = 1 << 11,
	E2_OPTION_FLAG_TREE = 1 << 12,
	//more flags for things to free when the config data is dumped
	E2_OPTION_FLAG_FREENAME = 1 << 14,
	E2_OPTION_FLAG_FREEGROUP = 1 << 15,
	E2_OPTION_FLAG_FREEDESC = 1 << 16,
	E2_OPTION_FLAG_FREETIP = 1 << 17,
	//flags for things to rebuild when config dialog is completed
	E2_OPTION_FLAG_BUILDICONS = 1 << 19, //clear icons cache
	E2_OPTION_FLAG_BUILDALL = 1 << 20,
	E2_OPTION_FLAG_BUILDPANES = 1 << 21,
	E2_OPTION_FLAG_BUILDLISTS = 1 << 22,
	E2_OPTION_FLAG_BUILDBARS = 1 << 23,
	E2_OPTION_FLAG_BUILDSAMEBARS = 1 << 24,
	//flags for 'extra' data structures to possibly rebuild when config dialog is completed
	E2_OPTION_FLAG_BUILDFILES = 1 << 25,	//dirty filetypes tree option
	E2_OPTION_FLAG_BUILDPLUGS = 1 << 26, //dirty plugins tree option
	E2_OPTION_FLAG_BUILDKEYS = 1 << 27, //dirty keybindings tree option
	E2_OPTION_FLAG_BUILDALIAS = 1 << 28, //dirty aliases tree option
} E2_OptionFlags;

typedef struct _E2_OptionTypeExtraInt
{
	gint min;
	gint max;
} E2_OptionTypeExtraInt;

typedef struct _E2_OptionTypeExtraSel
{
	gchar **def;
	gint def_count;
} E2_OptionTypeExtraSel;

//stored as set->ex.tree
typedef struct _E2_OptionTypeExtraTree
{
	gpointer model;
	//array of strings with default values for the tree
	gchar **def;
	//holds tree values in case the config file
	//has been read before the tree option was registed
//	gchar **unknown;
//	gint def_num;
	gboolean found_in_config_file;
	gint columns_num;
	GList *columns;
	gpointer selection_check_func;
	gpointer draggable_check_func;
	E2_OptionTreeTypeFlags flags; //flags set when registering a tree option
} E2_OptionTypeExtraTree;

typedef struct _E2_OptionTypeExtraColor
{
	GdkColor value;
} E2_OptionTypeExtraColor;

typedef struct _E2_OptionSet
{
	E2_OptionType type;
	gchar *name;	//constant string, 'internal' name of option, used for checking, finding
	gchar *group;	//probably always a newly-alllocated string
	gchar *desc;	//almost always a constant string
	gchar *tip;	//almost always a constant string
	gchar *depends;	//constant string, 'internal' name of option that must be true for this
							//one to be 'changeable', or can start with "!" for false precedent
	gint ival;
	gchar *sval;
//	gint idef;
//	gchar *sdef;
	
	//extra option data
	union _E2_OptionTypeExtra
	{
		E2_OptionTypeExtraInt num;
		E2_OptionTypeExtraSel sel;
		E2_OptionTypeExtraTree tree;
		E2_OptionTypeExtraColor color;
	} ex;
	GtkWidget *widget;	//config dialog widget with data for this option
	E2_OptionFlags flags;	//flags for destroying, rebuilding stuff related to the option
	gboolean hook_freezed;
	GHookList hook_value_changed;
} E2_OptionSet;

typedef gchar *_config_labels[42];	//make sure there's enough for all array items
_config_labels config_labels;
#define _C(d) config_labels[d]

gchar *default_config_file;

//to save option references
GHashTable *options_hash;
//GHashTable *options_queue; was for unknown options
GPtrArray *options_array;

void e2_option_setup_labels (void);
gboolean e2_option_set_config_dir (void);
gboolean e2_option_check_config_files (void);
void e2_option_disable_config_checks (void);
void e2_option_enable_config_checks (void);
void e2_option_refresh (gboolean reload, gboolean recreate);
void e2_option_set_trash_dir (void);
void e2_option_init (void);
void e2_option_read_from_string (gchar *f[]);
void e2_option_register (E2_OptionSet *set);
E2_OptionSet *e2_option_get (gchar *option);
E2_OptionSet *e2_option_get_simple (gchar *option);
//void *e2_option_void_get (E2_OptionSet *set, gchar *option);
void e2_option_tree_stores_clear (void);
E2_OptionSet *e2_option_attach_value_changed (gchar *option, GtkWidget *widget,
	gpointer func, gpointer data);
void e2_option_attach_value_changed_simple (E2_OptionSet *set, GtkWidget *widget,
	gpointer func, gpointer data);
gboolean e2_option_file_read (void);
void e2_option_file_write (void);

//void destroy_config ();

#include "e2_option_bool.h"
#include "e2_option_int.h"
#include "e2_option_str.h"
#include "e2_option_sel.h"
#include "e2_option_color.h"
#include "e2_option_tree.h"
#include "e2_option_unknown.h"

  /***********************************************/
 /***** functions from e2_option__default.c *****/
/***********************************************/

void e2_option_default_register (void);

  /******************************************/
 /***** functions from e2_option__io.c *****/
/******************************************/

//gboolean e2_option_read_from_file (gchar *fn);
//void e2_option_write_to_file (void);

  /**********************************************/
 /***** functions from e2_option__widget.c *****/
/**********************************************/

GtkWidget *e2_option_create_menu (GtkWidget *controller, GtkWidget *menu,
	E2_OptionSet *set, ...);
void e2_option_connect (GtkWidget *controller, gboolean  active);

#endif //ndef E2_OPTION_H
